import { FC, useEffect, useState } from "react";
import { ExitLayer, NavItem, SideBarBox } from "../styles/TopBarStyle";
import { useNavigate } from "react-router";

const NavigationMenu: FC = () => {
    const navigate = useNavigate();
    const handleClick = (loc: string) => {
        setIsNavMenuOpen(false);
        navigate(loc);
    };
    const locations: Array<string> = ["/", "/about", "CV", "/projects"];
    const [isPhone, setIsPhone] = useState(
        window.matchMedia("(min-width: 720px)").matches
    );
    const locationButtons = locations.map((location) => (
        <NavItem onClick={() => handleClick(location)}>{location}</NavItem>
    ));
    const [isNavMenuOpen, setIsNavMenuOpen] = useState<boolean>(false);
    useEffect(() => {
        const recheckIsPhone = () => {
            setIsPhone(window.matchMedia("(min-width: 720px)").matches);
        };

        window.addEventListener("resize", recheckIsPhone);
    });

    return (
        <>
            {isPhone ? (
                locationButtons
            ) : (
                <>
                    <button onClick={() => setIsNavMenuOpen(true)}>
                        <span className="material-symbols-outlined">menu</span>
                    </button>
                    <SideBarBox xPosition={isNavMenuOpen ? 0 : 20}>
                        {locationButtons}
                    </SideBarBox>
                    {isNavMenuOpen && (
                        <ExitLayer onClick={() => setIsNavMenuOpen(false)} />
                    )}
                </>
            )}
        </>
    );
};

export default NavigationMenu;
